/*
 * Geotools 2 - OpenSource mapping toolkit
 * (C) 2003, Geotools Project Managment Committee (PMC)
 * (C) 2000, Institut de Recherche pour le Dveloppement
 * (C) 1999, Pches et Ocans Canada
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation; either
 *    version 2.1 of the License, or (at your option) any later version.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 *
 *    You should have received a copy of the GNU Lesser General Public
 *    License along with this library; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *                   THIS IS A TEMPORARY CLASS
 *
 *    This is a placeholder for future <code>Unit</code> class.
 *    This skeleton will be removed when the real classes from
 *    JSR-108: Units specification will be publicly available.
 */
package org.geotools.resources.units;

// Utilitaires
import java.util.Enumeration;
import java.util.ListResourceBundle;
import java.util.NoSuchElementException;
import java.util.MissingResourceException;


/**
 * Liste de ressources s'adaptant  la langue de l'utilisateur. Cette classe
 * s'apparente  la classe {@link java.util.ListResourceBundle} standard du
 * Java, except qu'elle est lgrement plus conome en mmoire.
 *
 * @version 1.0
 * @author Martin Desruisseaux
 */
public class SymbolResources extends java.util.ResourceBundle {
    /**
     * Table des ressources adaptes
     *  la langue de l'utilisateur.
     */
    private final Object[] map;

    /**
     * Construit la table des ressources.
     *
     * @param contents Liste des cls et des valeurs qui y sont associes.
     *        Les objets se trouvant aux index pairs (0, 2, 4...) sont les
     *        cls, et les objets se trouvant aux index impairs sont les
     *        valeurs.
     *
     * @throws IllegalArgumentException Si une cl a t rpte deux fois.
     */
    protected SymbolResources(final Object[] contents) throws IllegalArgumentException {
        map=contents;
        for (int i=0; i<contents.length; i+=2) {
            final String key=contents[i].toString();
            for (int j=i; (j+=2)<contents.length;) {
                if (key.equals(contents[j])) {
                    throw new IllegalArgumentException("Duplicated key: "+key);
                }
            }
        }
    }

    /**
     * Renvoie un numrateur qui balayera toutes
     * les cls que possde cette liste de ressources.
     */
    public final Enumeration getKeys() {
        return new Enumeration() {
            private int i=0;

            public boolean hasMoreElements() {
                return i<map.length;
            }

            public Object nextElement() {
                if (i<map.length) {
                    final int i=this.i;
                    this.i += 2;
                    return map[i];
                } else {
                    throw new NoSuchElementException();
                }
            }
        };
    }

    /**
     * Renvoie la ressource associe  une cl donne. Cette mthode est dfinie
     * pour rpondre aux exigences de la classe {@link java.util.ResourceBundle}
     * et n'a gnralement pas besoin d'tre appelle directement.
     *
     * @param  key Cl dsignant la ressouce dsire (ne doit pas tre <code>null</code>).
     * @return La ressource demande, ou <code>null</code> si aucune ressource n'est
     *         dfinie pour cette cl.
     */
    protected final Object handleGetObject(final String key) {
        for (int i=0; i<map.length; i+=2) {
            if (key.equals(map[i])) {
                return map[i+1];
            }
        }
        return null;
    }
}
