/*
 * Units - Temporary implementation for Geotools 2
 * Copyright (C) 1998 University Corporation for Atmospheric Research (Unidata)
 *               1998 Bill Hibbard & al. (VisAD)
 *               1999 Pches et Ocans Canada
 *               2000 Institut de Recherche pour le Dveloppement
 *               2002 Centre for Computational Geography
 *
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Library General Public
 *    License as published by the Free Software Foundation; either
 *    version 2 of the License, or (at your option) any later version.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *    Library General Public License for more details (http://www.gnu.org/).
 *
 *
 *    This package is inspired from the units package of VisAD.
 *    Unidata and Visad's work is fully acknowledged here.
 *
 *                   THIS IS A TEMPORARY CLASS
 *
 *    This is a placeholder for future <code>Unit</code> class.
 *    This skeleton will be removed when the real classes from
 *    JSR-108: Units specification will be publicly available.
 */
package org.geotools.units;

// Entrs/sorties
import java.io.PrintStream;
import java.io.InputStream;
import java.io.Serializable;
import java.io.ObjectInputStream;
import java.io.ObjectStreamException;

// Collections
import java.util.Iterator;

// Divers
import org.geotools.util.WeakHashSet;
import org.geotools.resources.rsc.ResourceKeys;
import org.geotools.resources.rsc.Resources;
import org.geotools.resources.units.Quantities;
import org.geotools.resources.units.Units;


/**
 * Placeholder for future <code>Unit</code> class. This
 * skeleton will be removed when the real classes (from
 * <A HREF="http://www.jcp.org/jsr/detail/108.jsp">JSR-108:
 * Units specification</A>) will be publicly available.
 * <br><br>
 * <strong>IMPORTANT: future version will NOT be compatible
 * will this one. Remind, this is a temporary class!</strong>
 *
 * @version $Id: Unit.java,v 1.5 2002/11/04 20:38:59 crotwell Exp $
 * @author Steven R. Emmerson
 * @author Bill Hibbard
 * @author Martin Desruisseaux
 */
public abstract class Unit implements Serializable {
    /**
     * Serial number for interoperability with different versions.
     */
    private static final long serialVersionUID = 8745958719541785628L;
    
    /**
     * Banque des objets qui ont t prcdemment crs et
     * enregistrs par un appel  la mthode {@link #intern}.
     */
    private static final WeakHashSet pool=Prefix.pool; // Must be first!
    
    /**
     * Convenience constant for dimensionless unit.
     */
    public static final Unit DIMENSIONLESS = DerivedUnit.DIMENSIONLESS;
    
    /**
     * Convenience constant for base unit of angle.
     * Not a SI unit, but provides here for convenience.
     */
    public static final Unit RADIAN = get("rad");
    
    /**
     * Convenience constant for unit of angle.
     * Not a SI unit, but provides here for convenience.
     */
    public static final Unit DEGREE = get("\u00b0");
    
    /**
     * Convenience constant for base unit of length.
     */
    public static final Unit METRE = get("m");
    
    /**
     * Convenience constant for derived unit of length.
     */
    public static final Unit KILOMETRE = METRE.scale(1000);
    
    /**
     * Convenience constant for base unit of time.
     */
    public static final Unit SECOND = get("s");
    
    /**
     * Convenience constant for unit of time.
     * Not a SI unit, but provides here for convenience.
     */
    public static final Unit MILLISECOND = get("ms");
    
    /**
     * Convenience constant for unit of time.
     * Not a SI unit, but provides here for convenience.
     */
    public static final Unit DAY = get("d");
    
    /**
     * Convenience constant for base unit of mass.
     */
    public static final Unit KILOGRAM = get("kg");

    /**
     * Unit of arc-second. Used by the EPSG database.
     */
    public static final Unit ARC_SECOND = DEGREE.scale(1.0/3600);
    
    /**
     * Convenience constant for "Degrees Minutes Secondes" unit.
     * For example, this "unit" convert 12.5 into 123000 (i.e.
     * the concatenation of 1230'00"). In a strict sence, this
     * is a formatting issue rather than an unit transformation
     * issue. Such transformation would be better handle by the
     * {@link org.geotools.pt.AngleFormat} class. However, this
     * "unit" appears really often in the EPSG database, and we
     * need it for interoperability with legacy libraries.
     */
    public static final Unit DMS = (Unit) new DMSUnit(1).intern();
    
    /**
     * Convenience constant for "Degrees dot Minutes Secondes" unit.
     * For example, this "unit" convert 12.5 into 12.3 (i.e.
     * the concatenation of 1230'00"). In a strict sence, this
     * is a formatting issue rather than an unit transformation
     * issue. Such transformation would be better handle by the
     * {@link org.geotools.pt.AngleFormat} class. However, this
     * "unit" appears really often in the EPSG database, and we
     * need it for interoperability with legacy libraries.
     */
    public static final Unit SEXAGESIMAL_DEGREE = (Unit) new DMSUnit(10000).intern();
    
    /**
     * Symbole des units de cet objet <code>Unit</code> (par exemple "kg").
     * Ce champs sera initialis lors de la construction de chaque objet
     * <code>Unit</code> et ne sera jamais nul. Ce symbole peut commencer
     * par un des prfix numrs dans le champ <code>prefix</code>. C'est
     * le cas par exemple des symboles "kg" (kilogramme) et "km" (kilomtre).
     */
    /*public*/ final String symbol;
    
    /**
     * Ensemble des prfix qui peuvent tre combins avec le symbole de l'unit.
     * Cet ensemble peut contenir par exemple les prfix "milli" (m), "centi" (c) et
     * "kilo" (k) qui, combins avec les mtres (m), donneront les millimtres (mm),
     * centimtres (cm) ou kilomtre (km). Ce champ intervient lors des appels  la
     * mthode {@link #scale}. Il peut tre nul si aucun prfix n'est autoris pour
     * le symbole.
     */
    /*public*/ final PrefixSet prefix;
    
    /**
     * Construit une unit qui aura le symbole spcifi.
     * @param  symbol Symbole de ces units (ne doit pas tre nul).
     * @param  prefix Ensemble des prfix utilisables avec {@link #symbol},
     *         ou <code>null</code> s'il n'y en a aucun. Cet ensemble sera
     *         affect au champ {@link #prefix} et interviendra lors des
     *         appels  la mthode {@link #scale}.
     * @throws NullPointerException Si <code>symbol</code> est nul.
     */
    /*protected*/ Unit(final String symbol, final PrefixSet prefix) throws NullPointerException {
        this.symbol=symbol.trim();
        this.prefix=prefix;
    }
    
    /**
     * Retourne les units qui correspondent au symbole spcifi. Si plus d'une
     * unit correspond au symbole spcifi, une unit arbitraire sera choisie.
     * Si aucune unit n'a t trouve, alors cette mthode retourne <code>null</code>.
     *
     * @param  symbol Symbole des units recherches. Cet argument ne doit pas tre nul.
     * @return Les units demandes.
     */
    public static Unit get(final String symbol) {
        Object unit=null;
        Unit[] units=null;
        for (int i=0; i<3; i++) {
            switch (i) {
                case 2: units=getDefaultUnits(); // fallthrough
                case 1: unit=UnitFormat.DEFAULT.parse(symbol); break;
                case 0: unit=getCached(symbol);                break;
            }
            if (unit instanceof Unit) {
                return (Unit) unit;
            }
        }
        return null;
    }
    
    /**
     * Retourne l'ensemble des units prdfinies par dfaut. Les units seront
     * retournes sans ordre particulier. Si les units par dfaut n'ont pas pu
     * tre obtenues, cette mthode retourne <code>null</code>.
     */
    private static Unit[] getDefaultUnits() {
        final InputStream in=Unit.class.getClassLoader().getResourceAsStream(UnitSet.PATHNAME);
        if (in!=null) try {
            final ObjectInputStream oin=new ObjectInputStream(in);
            final Unit[] units=(Unit[]) oin.readObject();
            oin.close();
            /*
             * Appelle 'intern()' simplement par prcaution.
             * En principe, ce n'est pas ncessaire.
             */
            for (int i=0; i<units.length; i++) {
                units[i]=units[i].intern();
            }
            return units;
        } catch (Exception exception) {
            exception.printStackTrace();
        }
        return null;
    }
    
    /**
     * Recherche une unit correspondant au symbole spcifi. Cette mthode est temporaire.
     * Il serait plus efficace d'utiliser un objet {@link java.util.HashMap} qui ferait
     * correspondre les symboles avec des units.
     */
    static Unit getCached(final String symbol) {
        for (final Iterator it=pool.iterator(); it.hasNext();) {
            final Object object=it.next();
            if (object instanceof Unit) {
                final Unit unit=(Unit) object;
                if (unit.symbol.equals(symbol)) return unit;
            }
        }
        return null;
    }
    
    /**
     * Renvoie une unit identique  celle-ci, mais
     * avec un nouveau symbole et de nouveaux prfix.
     *
     * @param  symbol Nouveau symbole reprsentant cette unit. Si ce
     *         paramtre est nul, un symbole par dfaut sera cr.
     * @param  prefix Liste des prfix autoriss pour le symbole.
     * @return La mme unit, mais avec le nouveau symbole. Peut tre
     *         <code>this</code>, mais ne sera jamais <code>null</code>.
     */
    public abstract Unit rename(final String symbol, final PrefixSet prefix);
    
    /**
     * Retourne le nom de l'unit dans la langue de l'utilisateur.
     * Par exemple le symbole "m" sera traduit par "mtre" dans la
     * langue franaise. Si aucun nom n'est disponible pour l'unit
     * courante, retourne simplement son symbole.
     */
    public String getLocalizedName() {
        return Units.localize(symbol);
    }
    
    /**
     * Retourne la quantit que reprsente cette unit. Les quantits sont des chanes de
     * caractres qui dcrivent le paramtre physique mesur, comme "mass" ou "speed". Si
     * aucune quantit n'est dfinie pour cette unit, retourne <code>null</code>.
     */
    public abstract String getQuantityName();
    
    /**
     * Retourne la quantit que reprsente cette unit dans la langue de l'utilisateur.
     * Les quantits sont des chanes de caractres qui dcrivent le paramtre physique
     * mesur, comme "masse" ou "vitesse". Si aucune quantit n'est dfinie pour cette
     * unit, retourne <code>null</code>.
     */
    public String getLocalizedQuantityName() {
        return Quantities.localize(getQuantityName());
    }
    
    /**
     * lve ces units  une puissance entire. Notez que ce ne sont pas toutes les
     * units qui peuvent tre leves  une puissance. Par exemple les units de
     * temprature en degrs Celcius (C), en Fahrenheit (F) et la densit sigma-T
     * ne peuvent pas tre leves  une puissance autre que 0 et 1.
     *
     *
     * L'implmentation par dfaut retourne une unit sans dimension ou <code>this</code>
     * selon que <code>power</code> ait la valeur 0 ou 1 respectivement, et lance une exception
     * dans tous les autres cas.
     *
     * @param power La puissance  laquelle lever cette unit.
     * @return Les units rsultant de l'lvation des units
     *         <code>this</code>  la puissance <code>power</code>.
     * @throws UnitException Si ces units ne peuvent tre
     *         leves  une puissance autre que 0 et 1.
     *
     * @see #multiply
     * @see #divide
     * @see #scale
     * @see #shift
     */
    public Unit pow(final int power) throws UnitException {
        switch (power) {
            case 0:  return DerivedUnit.DIMENSIONLESS;
            case 1:  return this;
            default: throw new UnitException(Resources.format(
                                             ResourceKeys.ERROR_BAD_UNIT_POWER_$2,
                                             new Integer(power), this), this, null);
        }
    }
    
    /**
     * lve ces units  une puissance fractionnaire. Cette mthode est utile entre
     * autre pour prendre la racine carre d'un nombre, ce qui revient  l'lever  la
     * puissance . L'implmentation par dfaut appele la mthode {@link #pow(int)}
     * pour les puissances entires, et lance une exception dans tous les autres cas.
     *
     * @param power La puissance  laquelle lever cette unit.
     * @return Les units rsultant de l'lvation des units
     *         <code>this</code>  la puissance <code>power</code>.
     * @throws UnitException Si ces units ne peuvent tre
     *         leves  une puissance autre que 0 et 1.
     */
    public Unit pow(final double power) throws UnitException {
        final int integer=(int) power;
        if (integer==power) {
            return pow(integer);
        }
        throw new UnitException(Resources.format(
                                ResourceKeys.ERROR_BAD_UNIT_POWER_$2,
                                new Double(power), this), this, null);
    }
    
    /**
     * Multiplie cette unit par une autre unit.
     * L'implmentation par dfaut retourne <code>this</code> si <code>that</code> est
     * gal  une unit sans dimension, et lance une exception dams tous les autres cas.
     *
     * @param that L'unit par laquelle multiplier cette unit.
     * @return Le produit de <code>this</code> par <code>that</code>.
     * @throws UnitException Si les units <code>this</code>
     *         <code>that</code> ne peuvent pas tre multiplies.
     *
     * @see #pow
     * @see #divide
     * @see #scale
     * @see #shift
     */
    public Unit multiply(final Unit that) throws UnitException {
        if (DerivedUnit.DIMENSIONLESS.equals(that)) {
            return this;
        }
        throw illegalUnitOperationException(that);
    }
    /** Overrided by {@link SimpleUnit}.*/ Unit inverseMultiply(BaseUnit    that) throws UnitException {throw that.illegalUnitOperationException(this);}
    /** Overrided by {@link SimpleUnit}.*/ Unit inverseMultiply(DerivedUnit that) throws UnitException {throw that.illegalUnitOperationException(this);}
    /** Overrided by {@link SimpleUnit}.*/ Unit inverseMultiply(ScaledUnit  that) throws UnitException {throw that.illegalUnitOperationException(this);}
    
    /**
     * Divise cette unit par une autre unit.
     * L'implmentation par dfaut retourne <code>this</code> si <code>that</code> est
     * gal  une unit sans dimension, et lance une exception dams tous les autres cas.
     *
     * @param that L'unit par laquelle diviser cette unit.
     * @return Le quotient de <code>this</code> par <code>that</code>.
     * @throws UnitException Si les units <code>this</code>
     *         <code>that</code> ne peuvent pas tre divises.
     *
     * @see #pow
     * @see #multiply
     * @see #scale
     * @see #shift
     */
    public Unit divide(final Unit that) throws UnitException {
        if (DerivedUnit.DIMENSIONLESS.equals(that)) {
            return this;
        }
        throw illegalUnitOperationException(that);
    }
    /** Overrided by {@link SimpleUnit}.*/ Unit inverseDivide(BaseUnit    that) throws UnitException {throw that.illegalUnitOperationException(this);}
    /** Overrided by {@link SimpleUnit}.*/ Unit inverseDivide(DerivedUnit that) throws UnitException {throw that.illegalUnitOperationException(this);}
    /** Overrided by {@link SimpleUnit}.*/ Unit inverseDivide(ScaledUnit  that) throws UnitException {throw that.illegalUnitOperationException(this);}
    
    /**
     * Cre une nouvelle unit proportionnelle  cette unit. Par exemple
     * pour convertir en kilomtres des mesures exprimes en mtres, il
     * faut les diviser par 1000. On peut exprimer cette relation par le
     * code <code>Unit&nbsp;KILOMETRE=METRE.scale(1000)</code>.
     *
     * @param  amount Facteur par lequel il faudra diviser les valeurs
     *         exprimes selon ces units pour obtenir des valeurs
     *         exprimes selon les nouvelles units.
     * @return Les nouvelles units.
     *
     * @see #pow
     * @see #multiply
     * @see #divide
     * @see #shift
     */
    public abstract Unit scale(double amount);
    
    /**
     * Cre une nouvelle unit dcale par rapport  cette unit. Par exemple
     * pour convertir des degrs Kelvin en degrs Celsius, il faut soustraire
     * 273.15 aux degrs Kelvin. On peut exprimer cette relation par le code
     * <code>Unit&nbsp;CELCIUS=KELVIN.shift(273.15)</code>.
     *
     * @param  offset Constante  soustraire aux valeurs exprimes selon ces
     *         units pour obtenir des valeurs exprimes selon les nouvelles
     *         units.
     * @return Les nouvelles units.
     *
     * @see #pow
     * @see #multiply
     * @see #divide
     * @see #scale
     */
    public abstract Unit shift(double offset);
    
    /**
     * Indique si les units <code>this</code> et <code>that</code> sont compatibles.
     * Si elles le sont, alors les mthodes <code>convert</code> ne lanceront jamais
     * d'exception pour ces units. Toutes les classes du paquet <code>org.geotools.units</code>
     * garantissent que <code>this.canConvert(that)</code> donnera toujours le mme
     * rsultat que <code>that.canConvert(this)</code>. Si vous crivez vos propres
     * classes drives de <code>Unit</code>, vous devrez vous assurer que cette
     * condition reste respecte. Mais vitez d'appeller <code>that.canConvert(this)</code>
     *  l'intrieur de cette mthode sous peine de tomber dans une boucle sans fin.
     *
     * @param that Autre units avec laquelle on veut
     *        vrifier si ces units sont compatibles.
     * @return <code>true</code> Si l'on garantie que les mthodes
     *         <code>convert</code> ne lanceront pas d'exceptions.
     */
    public abstract boolean canConvert(Unit        that);
    /**SimpleUnit*/ boolean canConvert(BaseUnit    that) {return canConvert((Unit) that);}
    /**SimpleUnit*/ boolean canConvert(DerivedUnit that) {return canConvert((Unit) that);}
    
    /**
     * Effectue la conversion d'une mesure exprime selon d'autres units. Par
     * exemple <code>METRE.convert(1,&nbsp;FOOT)</code> retournera <code>0.3048</code>.
     *
     * @param value La valeur exprime selon les autres units (<code>fromUnit</code>).
     * @param fromUnit Les autres units.
     * @return La valeur convertie selon ces units (<code>this</code>).
     * @throws UnitException Si les units ne sont pas compatibles.
     */
    public abstract double convert(double value, Unit        fromUnit) throws UnitException;
    /**SimpleUnit*/ double convert(double value, BaseUnit    fromUnit) throws UnitException {return convert(value, (Unit) fromUnit);}
    /**SimpleUnit*/ double convert(double value, DerivedUnit fromUnit) throws UnitException {return convert(value, (Unit) fromUnit);}
    
    /**
     * Effectue sur-place la conversion de mesures exprimes selon d'autres
     * units. Les valeurs converties remplaceront les anciennes valeurs.
     *
     * @param  values En entr, les valeurs exprimes selon les autres units
     *         (<code>fromUnit</code>). En sortie, les valeurs exprimes selon ces
     *         units (<code>this</code>).
     * @param  fromUnit Les autres units.
     * @throws UnitException Si les units ne sont pas compatibles. Dans ce
     *         cas, aucun lment de <code>values</code> n'aura t modifi.
     */
    public abstract void convert(double[] values, Unit        fromUnit) throws UnitException;
    /**SimpleUnit*/ void convert(double[] values, BaseUnit    fromUnit) throws UnitException {convert(values, (Unit) fromUnit);}
    /**SimpleUnit*/ void convert(double[] values, DerivedUnit fromUnit) throws UnitException {convert(values, (Unit) fromUnit);}
    
    /**
     * Effectue sur-place la conversion de mesures exprimes selon d'autres
     * units. Les valeurs converties remplaceront les anciennes valeurs.
     *
     * @param  values En entr, les valeurs exprimes selon les autres
     *         units (<code>fromUnit</code>). En sortie, les valeurs exprimes
     *         selon ces units (<code>this</code>).
     * @param  fromUnit Les autres units.
     * @throws UnitException Si les units ne sont pas compatibles. Dans ce
     *         cas, aucun lment de <code>values</code> n'aura t modifi.
     */
    public abstract void convert(float[] values, Unit        fromUnit) throws UnitException;
    /**SimpleUnit*/ void convert(float[] values, BaseUnit    fromUnit) throws UnitException {convert(values, (Unit) fromUnit);}
    /**SimpleUnit*/ void convert(float[] values, DerivedUnit fromUnit) throws UnitException {convert(values, (Unit) fromUnit);}
    
    /**
     * Retourne un objet qui saura convertir selon ces units les valeurs exprimes
     * selon d'autres units. Cette mthode est avantageuse si on prvoie fare
     * plusieurs conversions, car la transformation  utiliser est dtermine une
     * fois pour toute.
     *
     * @param  fromUnit Units  partir de lesquel faire les conversions.
     * @return Une transformation des units <code>fromUnit</code>
     *         vers les units <code>this</code>. Cette mthode ne
     *         retourne jamais <code>null</code>.
     * @throws UnitException Si les units ne sont pas compatibles.
     */
    public abstract UnitTransform getTransform(Unit        fromUnit) throws UnitException;
    /**SimpleUnit*/ UnitTransform getTransform(BaseUnit    fromUnit) throws UnitException {return getTransform((Unit) fromUnit);}
    /**SimpleUnit*/ UnitTransform getTransform(DerivedUnit fromUnit) throws UnitException {return getTransform((Unit) fromUnit);}
    
    /**
     * Convertit une mesure vers d'autre units. Par exemple
     * <code>METRE.inverseConvert(1,&nbsp;FOOT)</code> retournera
     * <code>3.2808</code>. Cette mthode est l'inverse de la mthode
     * {@link #convert(double,Unit)}. Bien que n'tant pas destine 
     * tre appelle directement, les classes drives devront quand
     * mme la dfinir pour un fonctionnement correcte.
     *
     * @param  value La valeur exprime selon ces units (<code>this</code>).
     * @param  toUnit Les autres units.
     * @return La valeur convertie selon les autres units (<code>toUnit</code>).
     * @throws UnitException Si les units ne sont pas compatibles.
     */
    /*protected*/ abstract double inverseConvert(double value, Unit        toUnit) throws UnitException;
    /**SimpleUnit*/        double inverseConvert(double value, BaseUnit    toUnit) throws UnitException {return inverseConvert(value, (Unit) toUnit);}
    /**SimpleUnit*/        double inverseConvert(double value, DerivedUnit toUnit) throws UnitException {return inverseConvert(value, (Unit) toUnit);}
    
    /**
     * Effectue sur-place la conversion de mesures vers d'autres units.
     * Les valeurs converties remplaceront les anciennes valeurs. Cette
     * mthode est l'inverse de la mthode {@link #convert(double[],Unit)}.
     * Bien que n'tant pas destine  tre appelle directement, les classes
     * drives devront quand mme la dfinir pour un fonctionnement correcte.
     *
     * @param  values En entr, les valeur exprimes selon ces units
     *         (<code>this</code>). En sortie, les valeurs exprimes
     *         selon les autres units (<code>toUnit</code>).
     * @param  toUnit Les autres units.
     * @throws UnitException Si les units ne sont pas compatibles. Dans ce
     *         cas, aucun lment de <code>values</code> n'aura t modifi.
     */
    /*protected*/ abstract void inverseConvert(double[] values, Unit        toUnit) throws UnitException;
    /**SimpleUnit*/        void inverseConvert(double[] values, BaseUnit    toUnit) throws UnitException {inverseConvert(values, (Unit) toUnit);}
    /**SimpleUnit*/        void inverseConvert(double[] values, DerivedUnit toUnit) throws UnitException {inverseConvert(values, (Unit) toUnit);}
    
    /**
     * Effectue sur-place la conversion de mesures vers d'autres units.
     * Les valeurs converties remplaceront les anciennes valeurs. Cette
     * mthode est l'inverse de la mthode {@link #convert(float[],Unit)}.
     * Bien que n'tant pas destine  tre appelle directement, les classes
     * drives devront quand mme la dfinir pour un fonctionnement correcte.
     *
     * @param  values En entr, les valeur exprimes selon ces units
     *         (<code>this</code>). En sortie, les valeurs exprimes
     *         selon les autres units (<code>toUnit</code>).
     * @param  toUnit Les autres units.
     * @throws UnitException Si les units ne sont pas compatibles. Dans ce
     *         cas, aucun lment de <code>values</code> n'aura t modifi.
     */
    /*protected*/ abstract void inverseConvert(float[] values, Unit        toUnit) throws UnitException;
    /**SimpleUnit*/        void inverseConvert(float[] values, BaseUnit    toUnit) throws UnitException {inverseConvert(values, (Unit) toUnit);}
    /**SimpleUnit*/        void inverseConvert(float[] values, DerivedUnit toUnit) throws UnitException {inverseConvert(values, (Unit) toUnit);}
    
    /**
     * Retourne un objet qui saura convertir selon d'autres units les
     * valeurs exprimes selon ces units. Cette mthode est l'inverse
     * de {@link #getTransform}.
     *
     * @param  toUnit Units vers lesquel faire les conversions.
     * @return Une transformation des units <code>this</code>
     *         vers les units <code>toUnit</code>. Cette mthode
     *         ne retourne jamais <code>null</code>.
     * @throws UnitException Si les units ne sont pas compatibles.
     */
    /*protected*/ abstract UnitTransform getInverseTransform(Unit        toUnit) throws UnitException;
    /**SimpleUnit*/        UnitTransform getInverseTransform(BaseUnit    toUnit) throws UnitException {return getInverseTransform((Unit) toUnit);}
    /**SimpleUnit*/        UnitTransform getInverseTransform(DerivedUnit toUnit) throws UnitException {return getInverseTransform((Unit) toUnit);}
    
    /**
     * Retourne une exception  lancer lorsque
     * l'opration demande n'est pas permise.
     */
    final UnitException illegalUnitOperationException(Unit that) {
        return new UnitException(Resources.format(
                                 ResourceKeys.ERROR_BAD_UNIT_OPERATION_$2, this, that), this, that);
    }
    
    /**
     * Retourne une exception  lancer lorsque
     * les units ne sont pas compatibles.
     */
    final UnitException incompatibleUnitsException(Unit that) {
        return new UnitException(Resources.format(
                                 ResourceKeys.ERROR_NON_CONVERTIBLE_UNITS_$2, this, that), this, that);
    }
    
    /**
     * Aprs la lecture binaire, vrifie si les
     * unites lues existaient dj en mmoire.
     */
    final Object readResolve() throws ObjectStreamException {
        return intern();
    }
    
    /**
     * Retourne un exemplaire unique de cette unit. Une banque d'units, initialement
     * vide, est maintenue de faon interne par la classe <code>Unit</code>. Lorsque la
     * mthode <code>intern</code> est appele, elle recherchera des units gales 
     * <code>this</code> au sens de la mthode {@link #equals}. Si de telles units
     * sont trouves, elles seront retournes. Sinon, les units <code>this</code>
     * seront ajoutes  la banque de donnes en utilisant une rfrence faible
     * et cette mthode retournera <code>this</code>.
     * <br><br>
     * De cette mthode il s'ensuit que pour deux units <var>u</var> et <var>v</var>,
     * la condition <code>u.intern()==v.intern()</code> sera vrai si et seulement si
     * <code>u.equals(v)</code> est vrai.
     */
    /*protected*/ final Unit intern() {
        return (Unit) pool.canonicalize(this);
    }
    
    /**
     * Retourne un exemplaire unique de cette unit, quel que soit son symbole. Une banque d'units,
     * initialement vide, est maintenue de faon interne par la classe <code>Unit</code>. Lorsque la
     * mthode <code>internIgnoreSymbol</code> est appele, elle recherchera des units gales 
     * <code>this</code> au sens de la mthode {@link #equalsIgnoreSymbol}. Si de telles units
     * sont trouves, elles seront retournes. Sinon, les units <code>this</code> seront ajoutes
     *  la banque de donnes en utilisant une rfrence faible et cette mthode retournera <code>this</code>.
     * <br><br>
     * De cette mthode il s'ensuit que pour deux units <var>u</var> et <var>v</var>,
     * la condition <code>u.internIgnoreSymbol()==v.internIgnoreSymbol()</code> sera
     * gnralement vrai si <code>u.equalsIgnoreSymbol(v)</code> est vrai. Toutefois,
     * si la banque de donnes contient plusieurs units identiques en tout sauf leurs
     * symboles, alors il n'y a aucune garantie de quelle unit sera choisie par cette
     * mthode.
     */
    /*protected*/ final Unit internIgnoreSymbol() {
        synchronized (pool) {
            final Object canonical = pool.get(new Unamed());
            if (canonical instanceof Unit) {
                return (Unit) canonical;
            }
            pool.add(this);
            return this;
        }
    }
    
    /**
     * Indique si deux units sont gales et utilisent le mme symbole.
     */
    public boolean equals(final Object unit) {
        if (unit!=null) {
            if (unit instanceof Unamed) {
                return unit.equals(this);
            }
            if (getClass().equals(unit.getClass())) {
                final Unit cast = (Unit) unit;
                if (symbol.equals(cast.symbol)) {
                    if (equalsIgnoreSymbol(cast)) {
                        if (prefix==cast.prefix) return true;
                        if (prefix==null)        return false;
                        return prefix.equals(cast.prefix);
                    }
                }
            }
        }
        return false;
    }
    
    /**
     * Indique si deux units sont gales, en ignorant leurs symboles. Le
     * champs {@link #symbol} de chacune des deux units ne sera pas pris
     * en compte.
     */
    /*public*/ abstract boolean equalsIgnoreSymbol(Unit unit);
    
    /**
     * Retourne un code propre  cette unit. Le calcul de
     * ce code ne devrait pas prendre en compte le symbole
     * de l'unit.
     */
    public abstract int hashCode();
    
    /**
     * Retourne les symboles de ces units, par exemple "m/s".
     * S'il existe un symbole particulier pour la langue de
     * l'utilisateur, ce symbole sera retourn.
     */
    public String toString() {
        return symbol;
    }
    
    
    
    
    /**
     * Enveloppe des units qui seront compares sans tenir compte des symboles.
     * Cette classe est utilise par {@link #internIgnoreSymbol} afin de puiser
     * dans la banque d'units {@link #pool} n'importe quel unit de dimensions
     * appropries, quel que soit son symbole.
     *
     * @version 1.0
     * @author Martin Desruisseaux
     */
    private final class Unamed {
        /**
         * Renvoie le code des
         * units enveloppes.
         */
        public int hashCode() {
            return Unit.this.hashCode();
        }
        
        /**
         * Vrifie si les units enveloppes sont
         * gales aux units spcifies, sans tenir
         * compte de leurs symboles respectifs.
         */
        public boolean equals(final Object obj) {
            return (obj instanceof Unit) && equalsIgnoreSymbol((Unit) obj);
        }
    }
}
